pub enum RtcProducerSsrcBindingOutcome {
Learned,
Replaced,
Rejected,
}Expand description
Outcomes of authenticated producer SSRC binding changes.
Labels contain no session, media, RID or SSRC identity so source churn cannot increase the number of exported time series.
Variants
Learned
A negotiated encoding acquired its first SSRC binding.
Replaced
A negotiated encoding replaced an earlier SSRC binding.
Rejected
A packet could not claim a negotiated encoding or its SSRC was occupied.